From e00d145ca3d251e5c7c014114835e197a8a68425 Mon Sep 17 00:00:00 2001
From: ram <ram>
Date: Fri, 31 Jan 1992 19:10:22 +0000
Subject: [PATCH] When seeing to replace a transform, check that it has the
 same note as well as the same type.  This provides a way to have more than
 one transform with the same type signature.

---
 compiler/knownfun.lisp | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/compiler/knownfun.lisp b/compiler/knownfun.lisp
index 3fdcbd63f..cc6183065 100644
--- a/compiler/knownfun.lisp
+++ b/compiler/knownfun.lisp
@@ -7,7 +7,7 @@
 ;;; Scott Fahlman or slisp-group@cs.cmu.edu.
 ;;;
 (ext:file-comment
-  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/compiler/knownfun.lisp,v 1.13 1991/11/12 16:11:22 ram Exp $")
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/compiler/knownfun.lisp,v 1.14 1992/01/31 19:10:22 ram Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -152,7 +152,7 @@
 ;;; %Deftransform  --  Internal
 ;;;
 ;;;    Grab the Function-Info and enter the function, replacing any old one
 ;;; with the same type.
 ;;;
 (proclaim '(function %deftransform
 		     (t list function &optional (or string null))))
@@ -160,8 +160,10 @@
   (let* ((ctype (specifier-type type))
 	 (note (or note "optimize"))
 	 (info (function-info-or-lose name))
-	 (old (find ctype (function-info-transforms info)
-		    :key #'transform-type :test #'type=)))
+	 (old (find-if #'(lambda (x)
+			   (and (type= (transform-type x) ctype)
+				(string-equal (transform-note x) note)))
+		       (function-info-transforms info))))
     (if old
 	(setf (transform-function old) fun  (transform-note old) note)
 	(push (make-transform :type ctype :function fun :note note)
@@ -152,7 +152,7 @@
 ;;;
 ;;;    Grab the Function-Info and enter the function, replacing any old one
-;;; with the same type.
+;;; with the same type and note.
 ;;;
 (proclaim '(function %deftransform
-- 
GitLab